from cmd import run
from cmd import run as run_cmd #backward compatibility
from findfiles import find_files
from touch import touch
from template import mktemplate
